@@ -5,5 +5,11 @@ pub use problem::Problem;
 
 mod code;
 mod lint;
+#[cfg(test)]
+mod lint_test;
 mod lints;
+#[cfg(test)]
+mod lints_test;
 mod problem;
+#[cfg(test)]
+mod problem_test;
